/* MARS Network Monitoring Engine
   Copyright (C) 1999 Brian H. Trammell
   Copyright (C) 2002 Leapfrog Research & Development, LLC

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, it is available at 
	http:///www.gnu.org/copyleft/gpl.html, or by writing to the
	Free Software Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
*/

package org.altara.mars;

import java.util.*;
import java.net.*;
import org.altara.mars.engine.*;

/** ProbeFactory creates probes of an appropriate class for a
	given type of service. ProbeFactory is considered part of the
	data model, since a Service's ProbeFactory encapsulates
	how to test the service, and therefore what type of
	service it is.
	<p>
	ProbeFactory itself maps service type names ("http", "smtp", etc.)
	to ProbeFactory instances. The initialize() static method sets
	common initial values up for this map; the map may be added to by
	the registerFactory() method.
*/

public abstract class ProbeFactory implements java.io.Serializable {

	private static Map factoryMap = new TreeMap();

	public static void registerFactory(ProbeFactory fac) {
		factoryMap.put(fac.getName(),fac);
	}

	public static Iterator getRegisteredServiceTypes() {
		return factoryMap.keySet().iterator();
	}

	public static ProbeFactory getFactory(String name) {
		return (ProbeFactory)factoryMap.get(name);
	}

	private String name;

	protected ProbeFactory(String name) {
		this.name = name;
	}

	public String getName() {
		return name;
	}

	public abstract Probe createProbe(Service service, Map params);
	public abstract int getDefaultPort();
}
